@@ -2,13 +2,13 @@ import os
 
 from conan.internal import check_duplicated_generator
 from conan.internal.internal_tools import raise_on_universal_arch
-from conan.tools.apple.apple import is_apple_os, resolve_apple_flags
+from conan.tools.apple.apple import is_apple_os, resolve_apple_flags, apple_extra_flags
 from conan.tools.build import cmd_args_to_string, save_toolchain_args
 from conan.tools.build.cross_building import cross_building
 from conan.tools.build.flags import architecture_flag, build_type_flags, cppstd_flag, \
     build_type_link_flags, \
     libcxx_flags
-from conan.tools.env import Environment
+from conan.tools.env import Environment, VirtualBuildEnv
 from conan.tools.gnu.get_gnu_triplet import _get_gnu_triplet
 from conan.tools.microsoft import VCVars, msvc_runtime_flag, unix_path, check_min_vs, is_msvc
 from conan.errors import ConanException
@@ -104,6 +104,7 @@ class GnuToolchain:
         # -isysroot makes all includes for your library relative to the build directory
         self.apple_isysroot_flag = isysroot_flag
         self.apple_min_version_flag = min_flag
+        self.apple_extra_flags = apple_extra_flags(conanfile)
         # Default initial environment flags
         self._initialize_default_extra_env()
 
@@ -126,14 +127,18 @@ class GnuToolchain:
         ret = {}
         if not self._is_cross_building or not self._conanfile.settings.get_safe("os") == "Android":
             return ret
-
+        # Setting host if it was not already defined yet
+        arch = self._conanfile.settings.get_safe("arch")
+        android_target = {'armv7': 'armv7a-linux-androideabi',
+                          'armv8': 'aarch64-linux-android',
+                          'x86': 'i686-linux-android',
+                          'x86_64': 'x86_64-linux-android'}.get(arch)
+        if self.triplets_info["host"]["triplet"] is None:
+            self.triplets_info["host"]["triplet"] = android_target
+        # Automatic guessing made by Conan (need the NDK path variable defined)
+        conan_vars = {}
         ndk_path = self._conanfile.conf.get("tools.android:ndk_path", check_type=str)
-        if not ndk_path:
-            raise ConanException("You must provide a NDK path. Use 'tools.android:ndk_path' "
-                                 "configuration field.")
-
         if ndk_path:
-            arch = self._conanfile.settings.get_safe("arch")
             os_build = self._conanfile.settings_build.get_safe("os")
             ndk_os_folder = {
                 'Macos': 'darwin',
@@ -147,16 +152,11 @@ class GnuToolchain:
                 'WindowsCE': 'windows',
                 'WindowsStore': 'windows'
             }.get(os_build, "linux")
+            ext = ".cmd" if os_build == "Windows" else ""
             ndk_bin = os.path.join(ndk_path, "toolchains", "llvm", "prebuilt",
                                    f"{ndk_os_folder}-x86_64", "bin")
             android_api_level = self._conanfile.settings.get_safe("os.api_level")
-            android_target = {'armv7': 'armv7a-linux-androideabi',
-                              'armv8': 'aarch64-linux-android',
-                              'x86': 'i686-linux-android',
-                              'x86_64': 'x86_64-linux-android'}.get(arch)
-            os_build = self._conanfile.settings_build.get_safe('os')
-            ext = ".cmd" if os_build == "Windows" else ""
-            ret = {
+            conan_vars = {
                 "CC": os.path.join(ndk_bin, f"{android_target}{android_api_level}-clang{ext}"),
                 "CXX": os.path.join(ndk_bin, f"{android_target}{android_api_level}-clang++{ext}"),
                 "LD": os.path.join(ndk_bin, "ld"),
@@ -164,9 +164,19 @@ class GnuToolchain:
                 "RANLIB": os.path.join(ndk_bin, "llvm-ranlib"),
                 "AS": os.path.join(ndk_bin, f"{android_target}{android_api_level}-clang{ext}"),
                 "AR": os.path.join(ndk_bin, "llvm-ar"),
+                "ADDR2LINE": os.path.join(ndk_bin, "llvm-addr2line"),
+                "NM": os.path.join(ndk_bin, "llvm-nm"),
+                "OBJCOPY": os.path.join(ndk_bin, "llvm-objcopy"),
+                "OBJDUMP": os.path.join(ndk_bin, "llvm-objdump"),
+                "READELF": os.path.join(ndk_bin, "llvm-readelf"),
+                "ELFEDIT": os.path.join(ndk_bin, "llvm-elfedit")
             }
-            # Overriding host triplet
-            self.triplets_info["host"]["triplet"] = android_target
+        build_env = VirtualBuildEnv(self._conanfile, auto_generate=True).vars()
+        for var_name, var_path in conan_vars.items():
+            # User variables have more priority than Conan ones, so if it was defined within
+            # the build env then do nothing
+            if build_env.get(var_name) is None:
+                ret[var_name] = var_path
         return ret
 
     def _resolve_compilers_mapping_variables(self):
@@ -185,16 +195,6 @@ class GnuToolchain:
                     # https://github.com/conan-io/conan/issues/13780
                     compiler = unix_path(self._conanfile, compiler)
                     ret[env_var] = compiler  # User/tools ones have precedence
-        # Issue related: https://github.com/conan-io/conan/issues/15486
-        if self._is_cross_building and self._conanfile.conf_build:
-            compilers_build_mapping = (
-                self._conanfile.conf_build.get("tools.build:compiler_executables", default={},
-                                               check_type=dict)
-            )
-            if "c" in compilers_build_mapping:
-                ret["CC_FOR_BUILD"] = compilers_build_mapping["c"]
-            if "cpp" in compilers_build_mapping:
-                ret["CXX_FOR_BUILD"] = compilers_build_mapping["cpp"]
         return ret
 
     def _initialize_default_extra_env(self):
@@ -213,7 +213,16 @@ class GnuToolchain:
                                   "RANLIB": ":",
                                   "STRIP": ":"}
             extra_env_vars.update(self._resolve_compilers_mapping_variables())
-
+        # Issue related: https://github.com/conan-io/conan/issues/15486
+        if self._is_cross_building and self._conanfile.conf_build:
+            compilers_build_mapping = (
+                self._conanfile.conf_build.get("tools.build:compiler_executables", default={},
+                                               check_type=dict)
+            )
+            if "c" in compilers_build_mapping:
+                extra_env_vars["CC_FOR_BUILD"] = compilers_build_mapping["c"]
+            if "cpp" in compilers_build_mapping:
+                extra_env_vars["CXX_FOR_BUILD"] = compilers_build_mapping["cpp"]
         # Update the extra_env attribute with all the compiler values
         for env_var, env_value in extra_env_vars.items():
             self.extra_env.define(env_var, env_value)
@@ -245,6 +254,7 @@ class GnuToolchain:
         ret = [self.libcxx, self.cppstd, self.arch_flag, fpic, self.msvc_runtime_flag,
                self.sysroot_flag]
         apple_flags = [self.apple_isysroot_flag, self.apple_arch_flag, self.apple_min_version_flag]
+        apple_flags += self.apple_extra_flags
         conf_flags = self._conanfile.conf.get("tools.build:cxxflags", default=[], check_type=list)
         vs_flag = self._add_msvc_flags(self.extra_cxxflags)
         ret = ret + self.build_type_flags + apple_flags + self.extra_cxxflags + vs_flag + conf_flags
@@ -255,6 +265,7 @@ class GnuToolchain:
         fpic = "-fPIC" if self.fpic else None
         ret = [self.arch_flag, fpic, self.msvc_runtime_flag, self.sysroot_flag]
         apple_flags = [self.apple_isysroot_flag, self.apple_arch_flag, self.apple_min_version_flag]
+        apple_flags += self.apple_extra_flags
         conf_flags = self._conanfile.conf.get("tools.build:cflags", default=[], check_type=list)
         vs_flag = self._add_msvc_flags(self.extra_cflags)
         ret = ret + self.build_type_flags + apple_flags + self.extra_cflags + vs_flag + conf_flags
@@ -264,6 +275,7 @@ class GnuToolchain:
     def ldflags(self):
         ret = [self.arch_flag, self.sysroot_flag]
         apple_flags = [self.apple_isysroot_flag, self.apple_arch_flag, self.apple_min_version_flag]
+        apple_flags += self.apple_extra_flags
         conf_flags = self._conanfile.conf.get("tools.build:sharedlinkflags", default=[],
                                               check_type=list)
         conf_flags.extend(self._conanfile.conf.get("tools.build:exelinkflags", default=[],
