@@ -5,9 +5,9 @@ import textwrap
 from conan.api.output import ConanOutput
 from conans.client.graph.graph import RECIPE_CONSUMER, RECIPE_VIRTUAL, BINARY_SKIP, \
     BINARY_MISSING, BINARY_INVALID, Overrides, BINARY_BUILD, BINARY_EDITABLE_BUILD, BINARY_PLATFORM
-from conans.errors import ConanInvalidConfiguration, ConanException
-from conans.model.package_ref import PkgReference
-from conans.model.recipe_ref import RecipeReference
+from conan.errors import ConanException, ConanInvalidConfiguration
+from conan.api.model import PkgReference
+from conan.api.model import RecipeReference
 from conans.util.files import load
 
 
@@ -32,6 +32,7 @@ class _InstallPackageReference:
         self.depends = []  # List of package_ids of dependencies to other binaries of the same ref
         self.overrides = Overrides()
         self.ref = None
+        self.info = None
 
     @property
     def pref(self):
@@ -53,6 +54,7 @@ class _InstallPackageReference:
         result.options = node.conanfile.self_options.dumps().splitlines()
         result.nodes.append(node)
         result.overrides = node.overrides()
+        result.info = node.conanfile.info.serialize()  # ConanInfo doesn't have deserialize
         return result
 
     def add(self, node):
@@ -64,12 +66,14 @@ class _InstallPackageReference:
         self.nodes.append(node)
 
     def _build_args(self):
-        if self.binary != BINARY_BUILD:
+        if self.binary not in (BINARY_BUILD, BINARY_EDITABLE_BUILD):
             return None
         cmd = f"--requires={self.ref}" if self.context == "host" else f"--tool-requires={self.ref}"
-        cmd += f" --build={self.ref}"
+        compatible = "compatible:" if self.info and self.info.get("compatibility_delta") else ""
+        cmd += f" --build={compatible}{self.ref}"
         if self.options:
-            cmd += " " + " ".join(f"-o {o}" for o in self.options)
+            scope = "" if self.context == "host" else ":b"
+            cmd += " " + " ".join(f'-o{scope}="{o}"' for o in self.options)
         if self.overrides:
             cmd += f' --lockfile-overrides="{self.overrides}"'
         return cmd
@@ -83,7 +87,8 @@ class _InstallPackageReference:
                 "filenames": self.filenames,
                 "depends": self.depends,
                 "overrides": self.overrides.serialize(),
-                "build_args": self._build_args()}
+                "build_args": self._build_args(),
+                "info": self.info}
 
     @staticmethod
     def deserialize(data, filename, ref):
@@ -97,6 +102,7 @@ class _InstallPackageReference:
         result.filenames = data["filenames"] or [filename]
         result.depends = data["depends"]
         result.overrides = Overrides.deserialize(data["overrides"])
+        result.info = data.get("info")
         return result
 
 
@@ -121,6 +127,15 @@ class _InstallRecipeReference:
                 return True
         return False
 
+    def reduce(self):
+        result = _InstallRecipeReference()
+        result.ref = self.ref
+        result._node = self._node
+        result.depends = self.depends
+        result.packages = {pid: pkg for pid, pkg in self.packages.items()
+                           if pkg.binary in (BINARY_BUILD, BINARY_EDITABLE_BUILD)}
+        return result
+
     @property
     def node(self):
         return self._node
@@ -221,6 +236,7 @@ class _InstallConfiguration:
         self.filenames = []  # The build_order.json filenames e.g. "windows_build_order"
         self.depends = []  # List of full prefs
         self.overrides = Overrides()
+        self.info = None
 
     def __str__(self):
         return f"{self.ref}:{self.package_id} ({self.binary}) -> {[str(d) for d in self.depends]}"
@@ -229,6 +245,9 @@ class _InstallConfiguration:
     def need_build(self):
         return self.binary in (BINARY_BUILD, BINARY_EDITABLE_BUILD)
 
+    def reduce(self):
+        return self
+
     @property
     def pref(self):
         return PkgReference(self.ref, self.package_id, self.prev)
@@ -248,6 +267,7 @@ class _InstallConfiguration:
         # self_options are the minimum to reproduce state
         result.options = node.conanfile.self_options.dumps().splitlines()
         result.overrides = node.overrides()
+        result.info = node.conanfile.info.serialize()
 
         result.nodes.append(node)
         for dep in node.dependencies:
@@ -270,12 +290,14 @@ class _InstallConfiguration:
                     self.depends.append(dep.dst.pref)
 
     def _build_args(self):
-        if self.binary != BINARY_BUILD:
+        if self.binary not in (BINARY_BUILD, BINARY_EDITABLE_BUILD):
             return None
         cmd = f"--requires={self.ref}" if self.context == "host" else f"--tool-requires={self.ref}"
-        cmd += f" --build={self.ref}"
+        compatible = "compatible:" if self.info and self.info.get("compatibility_delta") else ""
+        cmd += f" --build={compatible}{self.ref}"
         if self.options:
-            cmd += " " + " ".join(f"-o {o}" for o in self.options)
+            scope = "" if self.context == "host" else ":b"
+            cmd += " " + " ".join(f'-o{scope}="{o}"' for o in self.options)
         if self.overrides:
             cmd += f' --lockfile-overrides="{self.overrides}"'
         return cmd
@@ -291,7 +313,8 @@ class _InstallConfiguration:
                 "filenames": self.filenames,
                 "depends": [d.repr_notime() for d in self.depends],
                 "overrides": self.overrides.serialize(),
-                "build_args": self._build_args()
+                "build_args": self._build_args(),
+                "info": self.info
                 }
 
     @staticmethod
@@ -306,6 +329,7 @@ class _InstallConfiguration:
         result.filenames = data["filenames"] or [filename]
         result.depends = [PkgReference.loads(p) for p in data["depends"]]
         result.overrides = Overrides.deserialize(data["overrides"])
+        result.info = data.get("info")
         return result
 
     def merge(self, other):
@@ -321,17 +345,41 @@ class _InstallConfiguration:
                 self.filenames.append(d)
 
 
+class ProfileArgs:
+    def __init__(self, args):
+        self._args = args
+
+    @staticmethod
+    def from_args(args):
+        pr_args = []
+        for context in "host", "build":
+            for f in "profile", "settings", "options", "conf":
+                s = "pr" if f == "profile" else f[0]
+                pr_args += [f'-{s}:{context[0]}="{v}"' for v in
+                            getattr(args, f"{f}_{context}") or []]
+        return ProfileArgs(" ".join(pr_args))
+
+    @staticmethod
+    def deserialize(data):
+        return ProfileArgs(data.get("args"))
+
+    def serialize(self):
+        return {"args": self._args}
+
+
 class InstallGraph:
     """ A graph containing the package references in order to be built/downloaded
     """
 
-    def __init__(self, deps_graph, order_by=None):
+    def __init__(self, deps_graph, order_by=None, profile_args=None):
         self._nodes = {}  # ref with rev: _InstallGraphNode
         order_by = order_by or "recipe"
         self._order = order_by
         self._node_cls = _InstallRecipeReference if order_by == "recipe" else _InstallConfiguration
         self._is_test_package = False
         self.reduced = False
+        self._profiles = {"self": profile_args} if profile_args is not None else {}
+        self._filename = None
         if deps_graph is not None:
             self._initialize_deps_graph(deps_graph)
             self._is_test_package = deps_graph.root.conanfile.tested_reference_str is not None
@@ -358,15 +406,24 @@ class InstallGraph:
                 self._nodes[ref] = install_node
             else:
                 existing.merge(install_node)
+        # Make sure that self is also updated
+        current = self._profiles.pop("self", None)
+        if current is not None:
+            self._profiles[self._filename] = current
+        new = other._profiles.get("self")
+        if new is not None:
+            self._profiles[other._filename] = new
 
     @staticmethod
     def deserialize(data, filename):
         legacy = isinstance(data, list)
-        order, data, reduced = ("recipe", data, False) if legacy else \
-            (data["order_by"], data["order"], data["reduced"])
+        order, data, reduced, profiles = ("recipe", data, False, {}) if legacy else \
+            (data["order_by"], data["order"], data["reduced"], data.get("profiles", {}))
         result = InstallGraph(None, order_by=order)
         result.reduced = reduced
         result.legacy = legacy
+        result._filename = filename
+        result._profiles = {k: ProfileArgs.deserialize(v) for k, v in profiles.items()}
         for level in data:
             for item in level:
                 elem = result._node_cls.deserialize(item, filename)
@@ -391,7 +448,7 @@ class InstallGraph:
         result = {}
         for k, node in self._nodes.items():
             if node.need_build:
-                result[k] = node
+                result[k] = node.reduce()
             else:  # Eliminate this element from the graph
                 dependencies = node.depends
                 # Find all consumers
@@ -451,16 +508,19 @@ class InstallGraph:
         install_order = self.install_order()
         result = {"order_by": self._order,
                   "reduced": self.reduced,
-                  "order": [[n.serialize() for n in level] for level in install_order]}
+                  "order": [[n.serialize() for n in level] for level in install_order],
+                  "profiles": {k: v.serialize() for k, v in self._profiles.items()}
+                  }
         return result
 
     def _get_missing_invalid_packages(self):
         missing, invalid = [], []
-        def analyze_package(package):
-            if package.binary == BINARY_MISSING:
-                missing.append(package)
-            elif package.binary == BINARY_INVALID:
-                invalid.append(package)
+
+        def analyze_package(pkg):
+            if pkg.binary == BINARY_MISSING:
+                missing.append(pkg)
+            elif pkg.binary == BINARY_INVALID:
+                invalid.append(pkg)
         for _, install_node in self._nodes.items():
             if self._order == "recipe":
                 for package in install_node.packages.values():
@@ -494,18 +554,18 @@ class InstallGraph:
             return "\n".join(errors)
         return None
 
-    def _raise_invalid(self, invalid):
+    @staticmethod
+    def _raise_invalid(invalid):
         msg = ["There are invalid packages:"]
         for package in invalid:
             node = package.nodes[0]
-            if node.cant_build and node.should_build:
-                binary, reason = "Cannot build for this configuration", node.cant_build
+            if node.conanfile.info.cant_build and node.should_build:
+                binary, reason = "Cannot build for this configuration", node.conanfile.info.cant_build
             else:
                 binary, reason = "Invalid", node.conanfile.info.invalid
             msg.append("{}: {}: {}".format(node.conanfile, binary, reason))
         raise ConanInvalidConfiguration("\n".join(msg))
 
-
     def _raise_missing(self, missing):
         # TODO: Remove out argument
         # TODO: A bit dirty access to .pref
@@ -528,8 +588,8 @@ class InstallGraph:
         missing_pkgs = "', '".join(list(sorted([str(pref.ref) for pref in missing_prefs])))
         if self._is_test_package:
             build_msg = "This is a **test_package** missing binary. You can use --build (for " \
-                        "all dependencies) or --build-test (exclusive for 'test_package' " \
-                        "dependencies) to define what can be built from sources"
+                        "all dependencies) or --build-test (exclusive for 'conan create' building " \
+                        "test_package' dependencies) to define what can be built from sources"
         else:
             if len(missing_prefs) >= 5:
                 build_str = "--build=missing"
